# -*- coding: utf-8 -*-
#
# --Description: 条件に合うトラックに色付け
import cri.atomcraft.debug as acdebug
import cri.atomcraft.project as acproject
import cri.atomcraft.view as acview

#-----------------------------------------------
# 設定
#-----------------------------------------------
# 色の識別名、RGB値の色リスト
color_dict = {"dirt"  :"178,34,34",  # トラック名に含まれる文字, 色
              "metal" :"192,192,192",
              "water" :"0,255,255",
              "wood"  :"218,165,32",
}
#-----------------------------------------------

acdebug.log("Robot: \"Coloring trucks\" Start.")

# 選択中のキューを取得
selected_cues = acproject.get_selected_objects("Cue")["data"]
if selected_cues == []:
    # キューを選択していない場合は、メッセージ出力して終了
    acdebug.warning("RobotError:Please select Cue.")
    exit()

cue = selected_cues[0] # 選択中の先頭キュー

# キュー直下のトラックを取得。
tracks = acproject.get_child_objects(cue, "Track")["data"]
if tracks == []:
    acdebug.warning("RobotError:Track not included.") # トラックが含まれていない
    exit()

for track in tracks:
    # トラック名を取得。
    track_name = acproject.get_value(track, "Name")["data"]
    # 色リストから色の識別名、RGB値を取り出し、条件に合うか調べる
    for color_name, rgb_color in color_dict.items():
        if color_name in track_name:
            # トラック名に色の識別文字が含まれている。トラックの色を変更
            acproject.set_color(track, rgb_color)
            continue # 色を設定したら次のトラックへ

# ログ・ダイアログ表示
acdebug.log("Robot: \"Coloring trucks\" Completed.")
acview.show_dialog("トラックの色設定完了", ["OK"])